@@ -41,32 +41,43 @@ inline namespace CPU_CAPABILITY {
 #define USE_SLEEF(sleef_code, non_sleef_code) non_sleef_code
 #endif
 
-template<int index, bool mask_val>
+template <int index, bool mask_val>
 struct BlendRegs {
   static float32x4_t impl(
-    const float32x4_t& a, const float32x4_t& b, float32x4_t& res);
+      const float32x4_t& a,
+      const float32x4_t& b,
+      float32x4_t& res);
 };
 
-template<int index>
-struct BlendRegs<index, true>{
+template <int index>
+struct BlendRegs<index, true> {
   static float32x4_t impl(
-      const float32x4_t& a, const float32x4_t& b, float32x4_t& res) {
+      const float32x4_t& a,
+      const float32x4_t& b,
+      float32x4_t& res) {
     return vsetq_lane_f32(vgetq_lane_f32(b, index), res, index);
   }
 };
 
-template<int index>
-struct BlendRegs<index, false>{
+template <int index>
+struct BlendRegs<index, false> {
   static float32x4_t impl(
-      const float32x4_t& a, const float32x4_t& b, float32x4_t& res) {
+      const float32x4_t& a,
+      const float32x4_t& b,
+      float32x4_t& res) {
     return vsetq_lane_f32(vgetq_lane_f32(a, index), res, index);
   }
 };
 
-template <> class Vectorized<float> {
-private:
+template <>
+struct is_vec_specialized_for<float> : std::bool_constant<true> {};
+
+template <>
+class Vectorized<float> {
+ private:
   float32x4_t values;
-public:
+
+ public:
   using value_type = float;
   using size_type = int;
   static constexpr size_type size() {
@@ -75,88 +86,81 @@ public:
   Vectorized() {}
   Vectorized(float32x4_t v) : values(v) {}
   Vectorized(float val) : values{vdupq_n_f32(val)} {}
-  Vectorized(float val0, float val1, float val2, float val3) :
-         values{val0, val1, val2, val3} {}
+  Vectorized(float val0, float val1, float val2, float val3)
+      : values{val0, val1, val2, val3} {}
   Vectorized(float (&arr)[4]) : Vectorized(arr[0], arr[1], arr[2], arr[3]) {}
   operator float32x4_t() const {
     return values;
   }
   template <int64_t mask>
-  static Vectorized<float> blend(const Vectorized<float>& a, const Vectorized<float>& b) {
+  static Vectorized<float> blend(
+      const Vectorized<float>& a,
+      const Vectorized<float>& b) {
     Vectorized<float> vec;
-    vec.values =
-      BlendRegs<0, (mask & 0x01)!=0>::impl(
-          a.values, b.values, vec.values);
-    vec.values =
-      BlendRegs<1, (mask & 0x02)!=0>::impl(
-          a.values, b.values, vec.values);
-    vec.values =
-      BlendRegs<2, (mask & 0x04)!=0>::impl(
-          a.values, b.values, vec.values);
-    vec.values =
-      BlendRegs<3, (mask & 0x08)!=0>::impl(
-          a.values, b.values, vec.values);
+    vec.values = BlendRegs < 0,
+    (mask & 0x01) != 0 > ::impl(a.values, b.values, vec.values);
+    vec.values = BlendRegs < 1,
+    (mask & 0x02) != 0 > ::impl(a.values, b.values, vec.values);
+    vec.values = BlendRegs < 2,
+    (mask & 0x04) != 0 > ::impl(a.values, b.values, vec.values);
+    vec.values = BlendRegs < 3,
+    (mask & 0x08) != 0 > ::impl(a.values, b.values, vec.values);
     return vec;
   }
-  static Vectorized<float> blendv(const Vectorized<float>& a, const Vectorized<float>& b,
-                              const Vectorized<float>& mask) {
+  static Vectorized<float> blendv(
+      const Vectorized<float>& a,
+      const Vectorized<float>& b,
+      const Vectorized<float>& mask) {
     // TODO
     // NB: This requires that each value, i.e., each uint value,
     // of the mask either all be zeros or all be 1s.
     // We perhaps need some kind of an assert?
     // But that will affect performance.
     Vectorized<float> vec(mask.values);
-    vec.values = vbslq_f32(
-        vreinterpretq_u32_f32(vec.values),
-        b.values,
-        a.values);
+    vec.values =
+        vbslq_f32(vreinterpretq_u32_f32(vec.values), b.values, a.values);
     return vec;
   }
-  template<typename step_t>
-  static Vectorized<float> arange(float base = 0.f, step_t step = static_cast<step_t>(1)) {
+  template <typename step_t>
+  static Vectorized<float> arange(
+      float base = 0.f,
+      step_t step = static_cast<step_t>(1)) {
     const Vectorized<float> base_vec(base);
     const Vectorized<float> step_vec(step);
     const Vectorized<float> step_sizes(0, 1, 2, 3);
     return fmadd(step_sizes, step_vec, base_vec);
   }
-  static Vectorized<float> set(const Vectorized<float>& a, const Vectorized<float>& b,
-                           int64_t count = size()) {
+  static Vectorized<float> set(
+      const Vectorized<float>& a,
+      const Vectorized<float>& b,
+      int64_t count = size()) {
     switch (count) {
       case 0:
         return a;
-      case 1:
-        {
-          Vectorized<float> vec;
-          static uint32x4_t mask_low = {0xFFFFFFFF, 0x0, 0x0, 0x0};
-          vec.values = vreinterpretq_f32_u32(mask_low);
-          vec.values = vbslq_f32(
-              vreinterpretq_u32_f32(vec.values),
-              b.values,
-              a.values);
-          return vec;
-        }
-      case 2:
-        {
-          Vectorized<float> vec;
-          static uint32x4_t mask_low = {0xFFFFFFFF, 0xFFFFFFFF, 0x0, 0x0};
-          vec.values = vreinterpretq_f32_u32(mask_low);
-          vec.values = vbslq_f32(
-              vreinterpretq_u32_f32(vec.values),
-              b.values,
-              a.values);
-          return vec;
-        }
-      case 3:
-        {
-          Vectorized<float> vec;
-          static uint32x4_t mask_low = {0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0};
-          vec.values = vreinterpretq_f32_u32(mask_low);
-          vec.values = vbslq_f32(
-              vreinterpretq_u32_f32(vec.values),
-              b.values,
-              a.values);
-          return vec;
-        }
+      case 1: {
+        Vectorized<float> vec;
+        static uint32x4_t mask_low = {0xFFFFFFFF, 0x0, 0x0, 0x0};
+        vec.values = vreinterpretq_f32_u32(mask_low);
+        vec.values =
+            vbslq_f32(vreinterpretq_u32_f32(vec.values), b.values, a.values);
+        return vec;
+      }
+      case 2: {
+        Vectorized<float> vec;
+        static uint32x4_t mask_low = {0xFFFFFFFF, 0xFFFFFFFF, 0x0, 0x0};
+        vec.values = vreinterpretq_f32_u32(mask_low);
+        vec.values =
+            vbslq_f32(vreinterpretq_u32_f32(vec.values), b.values, a.values);
+        return vec;
+      }
+      case 3: {
+        Vectorized<float> vec;
+        static uint32x4_t mask_low = {0xFFFFFFFF, 0xFFFFFFFF, 0xFFFFFFFF, 0x0};
+        vec.values = vreinterpretq_f32_u32(mask_low);
+        vec.values =
+            vbslq_f32(vreinterpretq_u32_f32(vec.values), b.values, a.values);
+        return vec;
+      }
     }
     return b;
   }
@@ -204,7 +208,7 @@ public:
     __at_align__ float tmp[size()];
     store(tmp);
     int mask = 0;
-    for (int i = 0; i < size(); ++ i) {
+    for (int i = 0; i < size(); ++i) {
       if (tmp[i] == 0.f) {
         mask |= (1 << i);
       }
@@ -218,7 +222,7 @@ public:
     __at_align__ float tmp[size()];
     store(tmp);
     for (const auto i : c10::irange(size())) {
-      if(_isnan(tmp[i]) || _isinf(tmp[i])) {
+      if (_isnan(tmp[i]) || _isinf(tmp[i])) {
         return true;
       }
     }
@@ -262,16 +266,15 @@ public:
   Vectorized<float> conj() const {
     return *this;
   }
-#define DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(name, sleef_name) \
-  Vectorized<float> name() const {                                      \
-    return USE_SLEEF(                                                   \
-        Vectorized<float>(sleef_name(values)),                          \
-        map(std::name)                                                  \
-    );                                                                  \
+#define DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(      \
+    name, sleef_name)                                                        \
+  Vectorized<float> name() const {                                           \
+    return USE_SLEEF(Vectorized<float>(sleef_name(values)), map(std::name)); \
   }
 
-#define DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(name)    \
-  DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(name, Sleef_##name##f4_u10)
+#define DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(name)      \
+  DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME( \
+      name, Sleef_##name##f4_u10)
 
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(acos)
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(acosh)
@@ -280,21 +283,26 @@ public:
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(atan)
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(atanh)
 
-#define DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(name, sleef_name) \
-  Vectorized<float> name(const Vectorized<float> &arg) const {          \
-    return USE_SLEEF(                                                   \
-        Vectorized<float>(sleef_name(values, arg.values)),              \
-        map2(arg, std::name)                                            \
-    );                                                                  \
+#define DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME( \
+    name, sleef_name)                                                    \
+  Vectorized<float> name(const Vectorized<float>& arg) const {           \
+    return USE_SLEEF(                                                    \
+        Vectorized<float>(sleef_name(values, arg.values)),               \
+        map2(arg, std::name));                                           \
   }
 
-#define DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC(name)           \
-  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(name, Sleef_##name##f4_u10)
+#define DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC(name)      \
+  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME( \
+      name, Sleef_##name##f4_u10)
 
   DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC(atan2)
-  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(copysign, Sleef_copysignf4)
+  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(
+      copysign,
+      Sleef_copysignf4)
   Vectorized<float> erf() const;
-  DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(erfc, Sleef_erfcf4_u15)
+  DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(
+      erfc,
+      Sleef_erfcf4_u15)
   Vectorized<float> erfinv() const {
     return map(calc_erfinv);
   }
@@ -304,8 +312,12 @@ public:
   Vectorized<float> exp_u20() const {
     return exp();
   }
-  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(fmod, Sleef_fmodf4)
-  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(hypot, Sleef_hypotf4_u05)
+  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(
+      fmod,
+      Sleef_fmodf4)
+  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(
+      hypot,
+      Sleef_hypotf4_u05)
   Vectorized<float> i0() const {
     return map(calc_i0);
   }
@@ -315,17 +327,19 @@ public:
   Vectorized<float> digamma() const {
     return map(calc_digamma);
   }
-  Vectorized<float> igamma(const Vectorized<float> &x) const {
+  Vectorized<float> igamma(const Vectorized<float>& x) const {
     return map2(x, calc_igamma);
   }
-  Vectorized<float> igammac(const Vectorized<float> &x) const {
+  Vectorized<float> igammac(const Vectorized<float>& x) const {
     return map2(x, calc_igammac);
   }
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(log)
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(log10)
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(log1p)
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(log2)
-  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(nextafter, Sleef_nextafterf4)
+  DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC_WITH_SLEEF_NAME(
+      nextafter,
+      Sleef_nextafterf4)
   Vectorized<float> frac() const;
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(sin)
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(sinh)
@@ -338,11 +352,11 @@ public:
     return map(at::native::floor_impl);
   }
   Vectorized<float> neg() const {
-    return Vectorized<float>(
-        vnegq_f32(values));
+    return Vectorized<float>(vnegq_f32(values));
   }
   Vectorized<float> round() const {
-    // We do not use std::round because we would like to round midway numbers to the nearest even integer.
+    // We do not use std::round because we would like to round midway numbers to
+    // the nearest even integer.
     return map(at::native::round_impl);
   }
   DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC(tan)
@@ -362,29 +376,34 @@ public:
   }
   DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC(pow)
   Vectorized<float> operator==(const Vectorized<float>& other) const {
-    return Vectorized<float>(vreinterpretq_f32_u32(vceqq_f32(values, other.values)));
+    return Vectorized<float>(
+        vreinterpretq_f32_u32(vceqq_f32(values, other.values)));
   }
 
   Vectorized<float> operator!=(const Vectorized<float>& other) const {
-    float32x4_t r0 = vreinterpretq_f32_u32(
-        vmvnq_u32(vceqq_f32(values, other.values)));
+    float32x4_t r0 =
+        vreinterpretq_f32_u32(vmvnq_u32(vceqq_f32(values, other.values)));
     return Vectorized<float>(r0);
   }
 
   Vectorized<float> operator<(const Vectorized<float>& other) const {
-    return Vectorized<float>(vreinterpretq_f32_u32(vcltq_f32(values, other.values)));
+    return Vectorized<float>(
+        vreinterpretq_f32_u32(vcltq_f32(values, other.values)));
   }
 
   Vectorized<float> operator<=(const Vectorized<float>& other) const {
-    return Vectorized<float>(vreinterpretq_f32_u32(vcleq_f32(values, other.values)));
+    return Vectorized<float>(
+        vreinterpretq_f32_u32(vcleq_f32(values, other.values)));
   }
 
   Vectorized<float> operator>(const Vectorized<float>& other) const {
-    return Vectorized<float>(vreinterpretq_f32_u32(vcgtq_f32(values, other.values)));
+    return Vectorized<float>(
+        vreinterpretq_f32_u32(vcgtq_f32(values, other.values)));
   }
 
   Vectorized<float> operator>=(const Vectorized<float>& other) const {
-    return Vectorized<float>(vreinterpretq_f32_u32(vcgeq_f32(values, other.values)));
+    return Vectorized<float>(
+        vreinterpretq_f32_u32(vcgeq_f32(values, other.values)));
   }
 
   Vectorized<float> eq(const Vectorized<float>& other) const;
@@ -396,22 +415,30 @@ public:
 };
 
 template <>
-Vectorized<float> inline operator+(const Vectorized<float>& a, const Vectorized<float>& b) {
+Vectorized<float> inline operator+(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
   return Vectorized<float>(vaddq_f32(a, b));
 }
 
 template <>
-Vectorized<float> inline operator-(const Vectorized<float>& a, const Vectorized<float>& b) {
+Vectorized<float> inline operator-(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
   return Vectorized<float>(vsubq_f32(a, b));
 }
 
 template <>
-Vectorized<float> inline operator*(const Vectorized<float>& a, const Vectorized<float>& b) {
+Vectorized<float> inline operator*(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
   return Vectorized<float>(vmulq_f32(a, b));
 }
 
 template <>
-Vectorized<float> inline operator/(const Vectorized<float>& a, const Vectorized<float>& b) {
+Vectorized<float> inline operator/(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
   return Vectorized<float>(vdivq_f32(a, b));
 }
 
@@ -420,82 +447,95 @@ inline Vectorized<float> Vectorized<float>::frac() const {
   return *this - this->trunc();
 }
 
-//Added sleef Implementation for Maximum
-Vectorized<float> inline maximum(const Vectorized<float>& a, const Vectorized<float>& b)  {
-  if(!a.has_inf_nan() && !b.has_inf_nan()){
-    return USE_SLEEF(
-      Vectorized<float>(Sleef_fmaxf4(a, b)),
-      Vectorized<float>(vmaxq_f32(a,b)));
-  }
-  else{
-    return Vectorized<float>(vmaxq_f32(a, b));
-  }
+template <>
+Vectorized<float> inline maximum(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
+  return Vectorized<float>(vmaxq_f32(a, b));
 }
 
 // Implements the IEEE 754 201X `minimum` operation, which propagates NaN if
 // either input is a NaN.
 template <>
-Vectorized<float> inline minimum(const Vectorized<float>& a, const Vectorized<float>& b) {
+Vectorized<float> inline minimum(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
   return Vectorized<float>(vminq_f32(a, b));
 }
 
 template <>
-Vectorized<float> inline clamp(const Vectorized<float>& a, const Vectorized<float>& min, const Vectorized<float>& max) {
+Vectorized<float> inline clamp(
+    const Vectorized<float>& a,
+    const Vectorized<float>& min,
+    const Vectorized<float>& max) {
   return minimum(max, maximum(min, a));
 }
 
 template <>
-Vectorized<float> inline clamp_max(const Vectorized<float>& a, const Vectorized<float>& max) {
+Vectorized<float> inline clamp_max(
+    const Vectorized<float>& a,
+    const Vectorized<float>& max) {
   return minimum(max, a);
 }
 
 template <>
-Vectorized<float> inline clamp_min(const Vectorized<float>& a, const Vectorized<float>& min) {
+Vectorized<float> inline clamp_min(
+    const Vectorized<float>& a,
+    const Vectorized<float>& min) {
   return maximum(min, a);
 }
 
 template <>
-Vectorized<float> inline operator&(const Vectorized<float>& a, const Vectorized<float>& b) {
-  return Vectorized<float>(vreinterpretq_f32_u32(vandq_u32(
-      vreinterpretq_u32_f32(a),
-      vreinterpretq_u32_f32(b))));
+Vectorized<float> inline operator&(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
+  return Vectorized<float>(vreinterpretq_f32_u32(
+      vandq_u32(vreinterpretq_u32_f32(a), vreinterpretq_u32_f32(b))));
 }
 
 template <>
-Vectorized<float> inline operator|(const Vectorized<float>& a, const Vectorized<float>& b) {
-  return Vectorized<float>(vreinterpretq_f32_u32(vorrq_u32(
-      vreinterpretq_u32_f32(a),
-      vreinterpretq_u32_f32(b))));
+Vectorized<float> inline operator|(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
+  return Vectorized<float>(vreinterpretq_f32_u32(
+      vorrq_u32(vreinterpretq_u32_f32(a), vreinterpretq_u32_f32(b))));
 }
 
 template <>
-Vectorized<float> inline operator^(const Vectorized<float>& a, const Vectorized<float>& b) {
-  return Vectorized<float>(vreinterpretq_f32_u32(veorq_u32(
-      vreinterpretq_u32_f32(a),
-      vreinterpretq_u32_f32(b))));
+Vectorized<float> inline operator^(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b) {
+  return Vectorized<float>(vreinterpretq_f32_u32(
+      veorq_u32(vreinterpretq_u32_f32(a), vreinterpretq_u32_f32(b))));
 }
 
-inline Vectorized<float> Vectorized<float>::eq(const Vectorized<float>& other) const {
+inline Vectorized<float> Vectorized<float>::eq(
+    const Vectorized<float>& other) const {
   return (*this == other) & Vectorized<float>(1.0f);
 }
 
-inline Vectorized<float> Vectorized<float>::ne(const Vectorized<float>& other) const {
+inline Vectorized<float> Vectorized<float>::ne(
+    const Vectorized<float>& other) const {
   return (*this != other) & Vectorized<float>(1.0f);
 }
 
-inline Vectorized<float> Vectorized<float>::gt(const Vectorized<float>& other) const {
+inline Vectorized<float> Vectorized<float>::gt(
+    const Vectorized<float>& other) const {
   return (*this > other) & Vectorized<float>(1.0f);
 }
 
-inline Vectorized<float> Vectorized<float>::ge(const Vectorized<float>& other) const {
+inline Vectorized<float> Vectorized<float>::ge(
+    const Vectorized<float>& other) const {
   return (*this >= other) & Vectorized<float>(1.0f);
 }
 
-inline Vectorized<float> Vectorized<float>::lt(const Vectorized<float>& other) const {
+inline Vectorized<float> Vectorized<float>::lt(
+    const Vectorized<float>& other) const {
   return (*this < other) & Vectorized<float>(1.0f);
 }
 
-inline Vectorized<float> Vectorized<float>::le(const Vectorized<float>& other) const {
+inline Vectorized<float> Vectorized<float>::le(
+    const Vectorized<float>& other) const {
   return (*this <= other) & Vectorized<float>(1.0f);
 }
 
@@ -505,7 +545,8 @@ inline void convert(const float* src, int32_t* dst, int64_t n) {
 #ifndef __msvc_cl__
 #pragma unroll
 #endif
-  for (i = 0; i <= (n - Vectorized<float>::size()); i += Vectorized<float>::size()) {
+  for (i = 0; i <= (n - Vectorized<float>::size());
+       i += Vectorized<float>::size()) {
     vst1q_s32(dst + i, vcvtq_s32_f32(vld1q_f32(src + i)));
   }
 #ifndef __msvc_cl__
@@ -522,7 +563,8 @@ inline void convert(const int32_t* src, float* dst, int64_t n) {
 #ifndef __msvc_cl__
 #pragma unroll
 #endif
-  for (i = 0; i <= (n - Vectorized<float>::size()); i += Vectorized<float>::size()) {
+  for (i = 0; i <= (n - Vectorized<float>::size());
+       i += Vectorized<float>::size()) {
     vst1q_f32(dst + i, vcvtq_f32_s32(vld1q_s32(src + i)));
   }
 #ifndef __msvc_cl__
@@ -534,48 +576,56 @@ inline void convert(const int32_t* src, float* dst, int64_t n) {
 }
 
 template <>
-Vectorized<float> inline fmadd(const Vectorized<float>& a, const Vectorized<float>& b, const Vectorized<float>& c) {
+Vectorized<float> inline fmadd(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b,
+    const Vectorized<float>& c) {
   return Vectorized<float>(vfmaq_f32(c, a, b));
 }
 
 template <>
-Vectorized<float> inline fmsub(const Vectorized<float>& a, const Vectorized<float>& b, const Vectorized<float>& c) {
+Vectorized<float> inline fmsub(
+    const Vectorized<float>& a,
+    const Vectorized<float>& b,
+    const Vectorized<float>& c) {
   return Vectorized<float>(vnegq_f32(vfmsq_f32(c, a, b)));
 }
 
-inline Vectorized<float> Vectorized<float>::erf() const{
-    // constants
-    const Vectorized<float> neg_zero_vec(-0.f);
-    const Vectorized<float> one_vec(1.0f);
-    const Vectorized<float> p(0.3275911f);
-    const Vectorized<float> p1(0.254829592f);
-    const Vectorized<float> p2(-0.284496736f);
-    const Vectorized<float> p3(1.421413741f);
-    const Vectorized<float> p4(-1.453152027f);
-    const Vectorized<float> p5(1.061405429f);
-    // sign(x)
-    auto sign_mask = neg_zero_vec & *this;
-    auto abs_vec = this->abs();
-    // t = 1 / (p * abs(x) + 1)
-    auto tmp0 = fmadd(p, abs_vec, one_vec);
-    auto t = one_vec / tmp0;
-    // r = p5 * t ^ 4 + p4 * t ^ 3 + p3 * t ^ 2 + p2 * t + p1
-    auto tmp1 = fmadd(p5, t, p4);
-    auto tmp2 = fmadd(tmp1, t, p3);
-    auto tmp3 = fmadd(tmp2, t, p2);
-    auto r = fmadd(tmp3, t, p1);
-    // - exp(- x * x)
-    auto pow_2 = (*this) * (*this);
-    auto neg_pow_2 = pow_2 ^ neg_zero_vec;
-    auto tmp4 = neg_pow_2.map(std::exp); // This can be swapped for a faster implementation of exp.
-    auto tmp5 = tmp4 ^ neg_zero_vec;
-    // erf(x) = sign(x) * (1 - r * t * exp(- x * x))
-    auto tmp6 = t * tmp5;
-    auto tmp7 = fmadd(tmp6, r, one_vec);
-    return tmp7 ^ sign_mask;
+inline Vectorized<float> Vectorized<float>::erf() const {
+  // constants
+  const Vectorized<float> neg_zero_vec(-0.f);
+  const Vectorized<float> one_vec(1.0f);
+  const Vectorized<float> p(0.3275911f);
+  const Vectorized<float> p1(0.254829592f);
+  const Vectorized<float> p2(-0.284496736f);
+  const Vectorized<float> p3(1.421413741f);
+  const Vectorized<float> p4(-1.453152027f);
+  const Vectorized<float> p5(1.061405429f);
+  // sign(x)
+  auto sign_mask = neg_zero_vec & *this;
+  auto abs_vec = this->abs();
+  // t = 1 / (p * abs(x) + 1)
+  auto tmp0 = fmadd(p, abs_vec, one_vec);
+  auto t = one_vec / tmp0;
+  // r = p5 * t ^ 4 + p4 * t ^ 3 + p3 * t ^ 2 + p2 * t + p1
+  auto tmp1 = fmadd(p5, t, p4);
+  auto tmp2 = fmadd(tmp1, t, p3);
+  auto tmp3 = fmadd(tmp2, t, p2);
+  auto r = fmadd(tmp3, t, p1);
+  // - exp(- x * x)
+  auto pow_2 = (*this) * (*this);
+  auto neg_pow_2 = pow_2 ^ neg_zero_vec;
+  auto tmp4 = neg_pow_2.map(
+      std::exp); // This can be swapped for a faster implementation of exp.
+  auto tmp5 = tmp4 ^ neg_zero_vec;
+  // erf(x) = sign(x) * (1 - r * t * exp(- x * x))
+  auto tmp6 = t * tmp5;
+  auto tmp7 = fmadd(tmp6, r, one_vec);
+  return tmp7 ^ sign_mask;
 }
 #undef DEFINE_SLEEF_COMPATIBLE_BINARY_ELEMENTWISE_FUNC
 #undef DEFINE_SLEEF_COMPATIBLE_UNARY_ELEMENTWISE_FUNC
 #endif /* defined(aarch64) */
 
-}} // namespace at::vec::CPU_CAPABILITY
+} // namespace CPU_CAPABILITY
+} // namespace at::vec
